"use strict";

var _parseCallbackRules = _interopRequireDefault(require("../utils/parse-callback-rules"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('parseCallbackRules', function () {
  it('Parse empty rules object :/', function () {
    var rules = {};
    var expected = {};
    expect((0, _parseCallbackRules.default)(rules)).toEqual(expected);
  });
  it('Parse without callbacks (1) ', function () {
    var rules = {
      name: 'required'
    };
    expect((0, _parseCallbackRules.default)(rules)).toEqual(rules);
  });
  it('Parse without callbacks (2)', function () {
    var rules = {
      name: ['required']
    };
    expect((0, _parseCallbackRules.default)(rules)).toEqual(rules);
  });
  it('Parse with callbacks (1)', function () {
    var rules = {
      name: ['required', {
        email: function email(ownProps) {
          return [1, 2];
        }
      }]
    };
    var expected = {
      name: ['required', {
        'email': [1, 2]
      }]
    };
    expect((0, _parseCallbackRules.default)(rules)).toEqual(expected);
  });
  it('Parse with callbacks (2)', function () {
    var rules = {
      name: ['required', {
        not_in: function not_in(ownProps) {
          return ownProps.results;
        }
      }, {
        required_if: ['age', 30]
      }]
    };
    var expected = {
      name: ['required', {
        not_in: [1, 2]
      }, {
        required_if: ['age', 30]
      }]
    };
    expect((0, _parseCallbackRules.default)(rules, [{
      results: [1, 2]
    }])).toEqual(expected);
  });
});