"use strict";

var _unflattenObject = require("../utils/unflatten-object");

describe('unflatten', function () {
  it('Unflatten single path without notation to object ', function () {
    expect((0, _unflattenObject.unflatten)('path', {})).toEqual({
      path: {}
    });
  });
  it('Unflatten path with dot notation to object', function () {
    expect((0, _unflattenObject.unflatten)('path.1', [])).toEqual({
      path: {
        1: []
      }
    });
  });
  it('Unflatten  dot notation path to deep object', function () {
    expect((0, _unflattenObject.unflatten)('path.1.x.$set', [])).toEqual({
      path: {
        1: {
          x: {
            $set: []
          }
        }
      }
    });
  });
});
describe('unflattenArrayStateUpdate', function () {
  it('(Array exists) Unflatten  dot notation path to $push state [update - immutability-helper]  ', function () {
    var state = {
      path: {
        items: []
      }
    };
    expect((0, _unflattenObject.unflattenArrayStateUpdate)(state, 'path.items', {})).toEqual({
      path: {
        items: {
          $push: [{}]
        }
      }
    });
  });
  it('(Array not exists) Unflatten  dot notation path to $set state  [update - immutability-helper]', function () {
    var state = {
      path: {}
    };
    expect((0, _unflattenObject.unflattenArrayStateUpdate)(state, 'path.items', {})).toEqual({
      path: {
        items: {
          $set: [{}]
        }
      }
    });
  });
});
describe('unflattenRemoveArrayStateUpdate', function () {
  it('Unflatten  dot notation path to $splice / remove  array state [update - immutability-helper] ', function () {
    expect((0, _unflattenObject.unflattenRemoveArrayStateUpdate)('path.items.0')).toEqual({
      path: {
        items: {
          $splice: [[0, 1]]
        }
      }
    });
  });
});